---
name: Bug report
about: File a bug report to help improve the project
title: '[BUG] '
labels: bug
assignees: ''

---

**Bug Description**
[A clear and concise description of the bug.]

**Expected behavior**
[A clear and concise description of what you expected to happen.]

**Screenshots**
[If applicable, add screenshots to help explain the issue.]

**System information**
[Run `carto info` in a terminal and add the output here, overwriting the
text below.]

```text
Raster Loader version: 0.1.dev32+gd59b0da
Python version: 3.11.0 | packaged by conda-forge |
Platform: Linux-5.10.16.3-microsoft-standard-WSL2-x86_64-with-glibc2.35
System version: Linux 5.10.16.3-microsoft-standard-WSL2
Machine: x86_64
Processor: x86_64
```

**Additional context**
[Add any other context about the problem here.]